@@ -1,6 +1,6 @@
 ;;; magit.el --- A Git porcelain inside Emacs  -*- lexical-binding:t; coding:utf-8 -*-
 
-;; Copyright (C) 2008-2025 The Magit Project Contributors
+;; Copyright (C) 2008-2026 The Magit Project Contributors
 
 ;; Author: Marius Vollmer <marius.vollmer@gmail.com>
 ;;     Jonas Bernoulli <emacs.magit@jonas.bernoulli.dev>
@@ -17,16 +17,16 @@
 ;; Homepage: https://github.com/magit/magit
 ;; Keywords: git tools vc
 
-;; Package-Version: 20251125.1404
-;; Package-Revision: 4800ace210d5
+;; Package-Version: 20260103.1925
+;; Package-Revision: 9cbdaf5ddfe8
 ;; Package-Requires: (
 ;;     (emacs        "28.1")
 ;;     (compat       "30.1")
-;;     (cond-let      "0.1")
+;;     (cond-let      "0.2")
 ;;     (llama         "1.0")
-;;     (magit-section "4.4")
+;;     (magit-section "4.5")
 ;;     (seq           "2.24")
-;;     (transient     "0.10")
+;;     (transient     "0.12")
 ;;     (with-editor   "3.4"))
 
 ;; SPDX-License-Identifier: GPL-3.0-or-later
@@ -773,11 +773,12 @@ For X11 something like ~/.xinitrc should work.\n"
   (require 'magit-stash)
   (require 'magit-blame)
   (require 'magit-submodule)
-  ;; The `provide' form may be missing so we have to
-  ;; try harder to ensure this is loaded exactly once.
-  (unless (or (featurep 'magit-autoloads)
+  (unless (or noninteractive
+              ;; The `provide' form may be missing, so we have to
+              ;; try harder to ensure this is loaded exactly once.
+              (featurep 'magit-autoloads)
               (autoloadp (symbol-function 'magit-patch))
-              (load "magit-autoloads" t))
+              (load "magit-autoloads" t t))
     (require 'magit-patch)
     (require 'magit-subtree)
     (require 'magit-ediff)
